#The COPYRIGHT file at the top level of this repository contains the full
#copyright notices and license terms.
from decimal import Decimal
from trytond.model import ModelView, ModelSQL, fields

__all__ = ['AccountBankReconciliation']

_ZERO = Decimal("0.0")


class AccountBankReconciliation(ModelView, ModelSQL):
    'Account Bank Reconciliation'
    __name__ = 'account.bank.reconciliation'
    #change name to bank_statement_line
    statement_line = fields.Many2One('account.bank.statement.line',
        'Bank Statement Line', ondelete='CASCADE')
    amount = fields.Numeric('Amount', digits=(16, 2), required=True)
    move_line = fields.Many2One('account.move.line', 'Move Line',
        required=False)

    @classmethod
    def __setup__(cls):
        super(AccountBankReconciliation, cls).__setup__()
        cls._error_messages.update({
                'delete_reconciled': ('Bank Reconciliation Line with amount '
                    '"%(amount)s" in statement_line "%(statement_line)s" '
                    'cannot be deleted')
                })

    @fields.depends('move_line', 'amount')
    def on_change_move_line(self):
        res = {}
        if self.move_line:
            if self.move_line.debit > _ZERO:
                res['amount'] = self.move_line.debit
            else:
                res['amount'] = -self.move_line.credit
        return res

    """
    @classmethod
    def write(cls, lines, vals):
        res = super(AccountBankReconciliation, cls).write(lines, vals)
        move_lines = set([x.move_line for x in lines])
        for move_line in move_lines:
            move_line.check_bank_lines()
        return res
    """
